@@ -3,7 +3,7 @@ import pytest
 from wsproto.connection import CLIENT, ConnectionState, SERVER
 from wsproto.events import AcceptConnection, Ping, RejectConnection, Request
 from wsproto.handshake import H11Handshake
-from wsproto.utilities import LocalProtocolError
+from wsproto.utilities import LocalProtocolError, RemoteProtocolError
 
 
 def test_successful_handshake() -> None:
@@ -19,19 +19,22 @@ def test_successful_handshake() -> None:
     assert client.state is ConnectionState.OPEN
     assert server.state is ConnectionState.OPEN
 
+    assert repr(client) == "H11Handshake(client=True, state=ConnectionState.OPEN)"
+    assert repr(server) == "H11Handshake(client=False, state=ConnectionState.OPEN)"
 
-def test_rejected_handshake() -> None:
-    client = H11Handshake(CLIENT)
+
+@pytest.mark.parametrize("http", [b"HTTP/1.0", b"HTTP/1.1"])
+def test_rejected_handshake(http: bytes) -> None:
     server = H11Handshake(SERVER)
-
-    server.receive_data(client.send(Request(host="localhost", target="/")))
-    assert isinstance(next(server.events()), Request)
-
-    client.receive_data(server.send(RejectConnection()))
-    assert isinstance(next(client.events()), RejectConnection)
-
-    assert client.state is ConnectionState.CLOSED
-    assert server.state is ConnectionState.CLOSED
+    with pytest.raises(RemoteProtocolError):
+        server.receive_data(
+            b"GET / " + http + b"\r\n"
+            b"Upgrade: WebSocket\r\n"
+            b"Connection: Upgrade\r\n"
+            b"Sec-WebSocket-Key: VQr8cvwwZ1fEk62PDq8J3A==\r\n"
+            b"Sec-WebSocket-Version: 13\r\n"
+            b"\r\n"
+        )
 
 
 def test_initiate_upgrade_as_client() -> None:
