@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
-
 import zlib
-from typing import cast, Dict, Optional, Sequence, TYPE_CHECKING, Union
+from typing import cast, Optional, Sequence, TYPE_CHECKING
 
 import pytest
-from _pytest.monkeypatch import MonkeyPatch
 
-import wsproto.extensions as wpext
-import wsproto.frame_protocol as fp
+from wsproto import extensions as wpext, frame_protocol as fp
 
 if TYPE_CHECKING:
     from mypy_extensions import TypedDict
@@ -45,12 +41,12 @@ class TestPerMessageDeflate:
         },
         {
             "client_no_context_takeover": True,
-            "client_max_window_bits": 8,
+            "client_max_window_bits": 9,
             "server_no_context_takeover": True,
             "server_max_window_bits": 9,
         },
         {"client_no_context_takeover": True, "server_max_window_bits": 9},
-        {"server_no_context_takeover": True, "client_max_window_bits": 8},
+        {"server_no_context_takeover": True, "client_max_window_bits": 9},
         {"client_max_window_bits": None, "server_max_window_bits": None},
         {},
     ]
@@ -351,7 +347,7 @@ class TestPerMessageDeflate:
         result2 = ext.frame_inbound_payload_data(proto, compressed_payload)
         assert result2 is fp.CloseReason.INVALID_FRAME_PAYLOAD_DATA
 
-    def test_inbound_bad_zlib_decoder_end_state(self, monkeypatch: MonkeyPatch) -> None:
+    def test_inbound_bad_zlib_decoder_end_state(self) -> None:
         compressed_payload = b"x" * 23
 
         ext = wpext.PerMessageDeflate()
@@ -374,9 +370,9 @@ class TestPerMessageDeflate:
             def flush(self) -> None:
                 raise zlib.error()
 
-        monkeypatch.setattr(ext, "_decompressor", FailDecompressor())
-
+        ext._decompressor = cast("zlib._Decompress", FailDecompressor())
         result2 = ext.frame_inbound_complete(proto, True)
+
         assert result2 is fp.CloseReason.INVALID_FRAME_PAYLOAD_DATA
 
     @pytest.mark.parametrize(
